package HTML::FormFu::Imager;
{
  $HTML::FormFu::Imager::VERSION = '1.00';
}

1;

=head1 NAME

HTML::FormFu::Imager - Imager.pm helpers for HTML::FormFu file uploads

=head1 DESCRIPTION

L<HTML::FormFu::Inflator::Imager> - inflate file uploads to L<Imager> 
objects.

L<HTML::FormFu::Transformer::Imager> - perform image transformations, such 
as scale, crop and rotate.

L<HTML::FormFu::Validator::Imager::Size> - ensure the image doesn't exceed a 
given pixel size.

=head1 SUPPORT

Mailing list:

L<http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/html-formfu>

Mailing list archives:

L<http://lists.scsys.co.uk/pipermail/html-formfu/>

=head1 BUGS

Please submit bugs / feature requests to 
L<https://github.com/fireartist/HTML-FormFu-Imager/issues> (preferred) or 
L<http://rt.perl.org>.

=head1 SEE ALSO

L<HTML::FormFu>

=head1 AUTHOR

Carl Franks

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007-2013 by Carl Franks

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

